@@ -40,7 +40,6 @@
  * On failure, returns a human-readable error message.
  */
 
-#include <alloca.h>
 #include <assert.h>
 #include <dirent.h>
 #include <errno.h>
@@ -157,7 +156,7 @@ static int nuke(const char *what)
 const char *run_init(const char *realroot, const char *console,
 		     const char *init, char **initargs)
 {
-	struct stat rst, cst, ist;
+	struct stat rst, cst;
 	struct statfs sfs;
 	int confd;
 
